rotor returns the numbers of tubes that can and cannot be loaded
in a centrifuge rotor and optionally shows various ways to balance a certain
number of tubes.
rotor(n, k = NULL, seed = 1, elapse = 1)rotor returns a list with two components:
checka list with three components:
valida vector containing the numbers of tubes that can be loaded.
invalida vector containing the numbers of tubes that cannot be loaded.
loada list with three components:
kthe number of tubes.
decomposea data frame showing different ways to decompose k.
holea data frame showing hole positions to load tubes.
visuala list of rotor images showing hole positions to load tubes.
an integer, the number of rotor holes.
an integer, the number of tubes (optional).
an integer, the seed for random number generation. Setting a seed
ensures the reproducibility of the result. See set.seed for
more details.
an integer, the constrained time in seconds for random sampling.
The number of rotor holes n ranges from 4 to
48.
Sivek G. On vanishing sums of distinct roots of unity. Integers.
2010;10(3):365-8.
Peil O, Hauryliuk V. A new spin on spinning your
samples: balancing rotors in a non-trivial manner. arXiv preprint
arXiv:1004.3671. 2010 Apr 21.
rotorVerify for verifying the balance of pre-existing
tube configurations.