rotorEqual returns the positions of rotor buckets that must be loaded
or empty to balance tubes of equal mass.
rotorEqual(n, k, seed = 2019)rotorEqual returns a list with two components:
loadeda vector containing the positions of rotor buckets that must be loaded.
emptya vector containing the positions of rotor buckets that must be empty.
rotorEqual also plots a
schematic diagram of the centrifuge rotor.
an integer, the number of rotor buckets.
an integer, the number of tubes.
an integer, the seed for random number generation. Setting a seed
ensures the reproducibility of the result. See set.seed for
more details.
The number of rotor buckets n ranges from 4 to
48. The number of tubes k must be greater than 0 and
smaller than the number of rotor buckets n.
Sivek G. On vanishing sums of distinct roots of unity. Integers.
2010;10(3):365-8.
Peil O, Hauryliuk V. A new spin on spinning your
samples: balancing rotors in a non-trivial manner. arXiv preprint
arXiv:1004.3671. 2010 Apr 21.
rotorCheck for checking centrifuge rotors and
rotorUnequal for balancing tubes of unequal mass.